---
template: mainpanel
source_form: markdown
name: Why not Micropython?
updated: July 2015
title: Why not Micropython?
---
Why not micropython? Micropython is **ace** . If your device is large enough to
support the micropython runtime, use it! The aim of this is on the really small
microcontrollers- the ones too small to even support micropython - like
an MSP430, or an Atmega 8A or similarly tiny MCU.
